from django.contrib import admin
from imaging.models import *

class ImageAdmin(admin.ModelAdmin):
  exclude = ['ordering', 'content_type']
  list_display = ('name', 'title')

admin.site.register(Image, ImageAdmin)



from imagekit.specs import ImageSpec 
from imagekit import processors 

class ResizeImagingThumb(processors.Resize): 
  width = 200 
  height = 200 
  crop = True

class ResizeSmallThumb(processors.Resize): 
  width = 200 
  height = 200 
  crop = True

class ResizeDisplay(processors.Resize):
  width = 600 

class ImagingThumbnail(ImageSpec): 
  access_as = 'imaging_thumbnail' 
  pre_cache = True 
  processors = [ResizeImagingThumb] 

class Display(ImageSpec):
  processors = [ResizeDisplay]

class SmallThumbnail(ImageSpec): 
  access_as = 'small_thumbnail' 
  pre_cache = True 
  processors = [ResizeSmallThumb] 



from django.db import models
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes import generic
from django.conf import settings

try:
  from imagekit.models import ImageModel
except ImportError:
  raise ImportError('Django Imaging needs imagekit to work. Please install imagekit: easy_install django-imagekit')

DEFAULT_IMAGING_SETTINGS = {
    'image_dir' : 'imaging_photos',
    'specs': 'imaging.specs'
    }

try:
  IMAGING_SETTINGS = settings.IMAGING_SETTINGS
except:
  IMAGING_SETTINGS = DEFAULT_IMAGING_SETTINGS

class Image(ImageModel):
  name = models.CharField(max_length=200)
  alt = models.CharField(max_length=200, null=True, blank=True)
  title = models.CharField(max_length=200, null=True, blank=True)
  image = models.ImageField(upload_to=IMAGING_SETTINGS['image_dir'])
  ordering = models.PositiveIntegerField(null=True, blank=True)
  content_type = models.ForeignKey(ContentType, null=True, blank=True)
  object_id = models.PositiveIntegerField(null=True, blank=True)
  content_object = generic.GenericForeignKey('content_type', 'object_id')

  class Meta:
    ordering = ('ordering', 'name')
    permissions = (
        ('imaging_upload_images', "Can upload using AJAX"),
        ('imaging_delete_images', "Can delete using AJAX"),
        )

  class IKOptions:
    spec_module = IMAGING_SETTINGS['specs']
    cache_dir = IMAGING_SETTINGS['image_dir']
    image_field = 'image'
    cache_filename_format = "%(specname)s/%(filename)s.%(extension)s"

  def __unicode__(self):
    return self.name



from django.conf.urls.defaults import *

urlpatterns = patterns('imaging.views',
    url(r'^iframe_form/$', 'iframe_form', name="imaging_iframe_form"),
    url(r'^ajax_delete/$', 'ajax_image_removal', name="imaging_image_removal"),
    )



from imaging.models import *
from imaging.forms import *
from django.http import Http404, HttpResponse
from django.shortcuts import render_to_response
from django.template.context import RequestContext
from django.contrib.auth.decorators import login_required, permission_required
from django.utils import simplejson
from settings import MEDIA_ROOT
from django.core.files import File

# Create your views here.

def iframe_form(request):
  if request.method == 'POST':
    form = AjaxUploadForm(request.POST, request.FILES)
    if form.is_valid():
      new_image = form.save()
      response_dict = { # data that will be serialized by json
          'title':form.cleaned_data['title'],
          'alt'  :form.cleaned_data['alt'],
          'name' :form.cleaned_data['name'][:25],
          'id'   :new_image.pk,
          'image':new_image.imaging_thumbnail.url,
          }
      form = AjaxUploadForm()
      return render_to_response('iframe_form.html',
          { 'form' : form, 'callback': simplejson.dumps(response_dict) },
          context_instance=RequestContext(request))
    else:
      return render_to_response('iframe_form.html',
          { 'form' : form },
          context_instance=RequestContext(request))
  else:
    form = AjaxUploadForm()
    return render_to_response('iframe_form.html',
        { 'form' : form },
        context_instance=RequestContext(request))
iframe_form = permission_required('imaging.upload_images')(iframe_form)
 
def ajax_image_removal(request):
  if request.method == 'POST':
    image_id = request.POST.get('id', '0')
    if image_id > 0:
      try:
        image = Image.objects.get(pk=image_id)
        image.delete()
      except:
        return HttpResponse("fail");
      return HttpResponse("ok");
    else:
      return HttpResponse("fail");
  else:
    return HttpResponse("fail");

ajax_image_removal = permission_required('imaging.ajax_delete_images')(ajax_image_removal)
